@@ -17,10 +17,13 @@
 from .services.asset_service import AssetServiceClient
 from .services.asset_service import AssetServiceAsyncClient
 
+from .types.asset_service import AnalyzeIamPolicyLongrunningMetadata
 from .types.asset_service import AnalyzeIamPolicyLongrunningRequest
 from .types.asset_service import AnalyzeIamPolicyLongrunningResponse
 from .types.asset_service import AnalyzeIamPolicyRequest
 from .types.asset_service import AnalyzeIamPolicyResponse
+from .types.asset_service import AnalyzeMoveRequest
+from .types.asset_service import AnalyzeMoveResponse
 from .types.asset_service import BatchGetAssetsHistoryRequest
 from .types.asset_service import BatchGetAssetsHistoryResponse
 from .types.asset_service import BigQueryDestination
@@ -39,6 +42,9 @@ from .types.asset_service import ListAssetsRequest
 from .types.asset_service import ListAssetsResponse
 from .types.asset_service import ListFeedsRequest
 from .types.asset_service import ListFeedsResponse
+from .types.asset_service import MoveAnalysis
+from .types.asset_service import MoveAnalysisResult
+from .types.asset_service import MoveImpact
 from .types.asset_service import OutputConfig
 from .types.asset_service import OutputResult
 from .types.asset_service import PartitionSpec
@@ -50,6 +56,7 @@ from .types.asset_service import SearchAllResourcesResponse
 from .types.asset_service import UpdateFeedRequest
 from .types.asset_service import ContentType
 from .types.assets import Asset
+from .types.assets import AttachedResource
 from .types.assets import ConditionEvaluation
 from .types.assets import IamPolicyAnalysisResult
 from .types.assets import IamPolicyAnalysisState
@@ -58,15 +65,20 @@ from .types.assets import Resource
 from .types.assets import ResourceSearchResult
 from .types.assets import TemporalAsset
 from .types.assets import TimeWindow
+from .types.assets import VersionedResource
 
 __all__ = (
     "AssetServiceAsyncClient",
+    "AnalyzeIamPolicyLongrunningMetadata",
     "AnalyzeIamPolicyLongrunningRequest",
     "AnalyzeIamPolicyLongrunningResponse",
     "AnalyzeIamPolicyRequest",
     "AnalyzeIamPolicyResponse",
+    "AnalyzeMoveRequest",
+    "AnalyzeMoveResponse",
     "Asset",
     "AssetServiceClient",
+    "AttachedResource",
     "BatchGetAssetsHistoryRequest",
     "BatchGetAssetsHistoryResponse",
     "BigQueryDestination",
@@ -90,6 +102,9 @@ __all__ = (
     "ListAssetsResponse",
     "ListFeedsRequest",
     "ListFeedsResponse",
+    "MoveAnalysis",
+    "MoveAnalysisResult",
+    "MoveImpact",
     "OutputConfig",
     "OutputResult",
     "PartitionSpec",
@@ -103,4 +118,5 @@ __all__ = (
     "TemporalAsset",
     "TimeWindow",
     "UpdateFeedRequest",
+    "VersionedResource",
 )
