@@ -45,10 +45,18 @@ class AssetServiceAsyncClient:
     DEFAULT_ENDPOINT = AssetServiceClient.DEFAULT_ENDPOINT
     DEFAULT_MTLS_ENDPOINT = AssetServiceClient.DEFAULT_MTLS_ENDPOINT
 
+    access_level_path = staticmethod(AssetServiceClient.access_level_path)
+    parse_access_level_path = staticmethod(AssetServiceClient.parse_access_level_path)
+    access_policy_path = staticmethod(AssetServiceClient.access_policy_path)
+    parse_access_policy_path = staticmethod(AssetServiceClient.parse_access_policy_path)
     asset_path = staticmethod(AssetServiceClient.asset_path)
 
     feed_path = staticmethod(AssetServiceClient.feed_path)
     parse_feed_path = staticmethod(AssetServiceClient.parse_feed_path)
+    service_perimeter_path = staticmethod(AssetServiceClient.service_perimeter_path)
+    parse_service_perimeter_path = staticmethod(
+        AssetServiceClient.parse_service_perimeter_path
+    )
     common_billing_account_path = staticmethod(
         AssetServiceClient.common_billing_account_path
     )
@@ -864,8 +872,8 @@ class AssetServiceAsyncClient:
                    the word "key".
                 -  ``state:ACTIVE`` to find Cloud resources whose state
                    contains "ACTIVE" as a word.
-                -  ``NOT state:ACTIVE`` to find {{gcp_name}} resources
-                   whose state doesn't contain "ACTIVE" as a word.
+                -  ``NOT state:ACTIVE`` to find Cloud resources whose
+                   state doesn't contain "ACTIVE" as a word.
                 -  ``createTime<1609459200`` to find Cloud resources
                    that were created before "2021-01-01 00:00:00 UTC".
                    1609459200 is the epoch timestamp of "2021-01-01
@@ -1221,8 +1229,8 @@ class AssetServiceAsyncClient:
         [google.longrunning.Operation][google.longrunning.Operation],
         which allows you to track the operation status. We recommend
         intervals of at least 2 seconds with exponential backoff retry
-        to poll the operation result. The metadata contains the request
-        to help callers to map responses to requests.
+        to poll the operation result. The metadata contains the metadata
+        for the long-running operation.
 
         Args:
             request (:class:`google.cloud.asset_v1.types.AnalyzeIamPolicyLongrunningRequest`):
@@ -1271,12 +1279,67 @@ class AssetServiceAsyncClient:
             response,
             self._client._transport.operations_client,
             asset_service.AnalyzeIamPolicyLongrunningResponse,
-            metadata_type=asset_service.AnalyzeIamPolicyLongrunningRequest,
+            metadata_type=asset_service.AnalyzeIamPolicyLongrunningMetadata,
         )
 
         # Done; return the response.
         return response
 
+    async def analyze_move(
+        self,
+        request: asset_service.AnalyzeMoveRequest = None,
+        *,
+        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> asset_service.AnalyzeMoveResponse:
+        r"""Analyze moving a resource to a specified destination
+        without kicking off the actual move. The analysis is
+        best effort depending on the user's permissions of
+        viewing different hierarchical policies and
+        configurations. The policies and configuration are
+        subject to change before the actual resource migration
+        takes place.
+
+        Args:
+            request (:class:`google.cloud.asset_v1.types.AnalyzeMoveRequest`):
+                The request object. The request message for performing
+                resource move analysis.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.asset_v1.types.AnalyzeMoveResponse:
+                The response message for resource
+                move analysis.
+
+        """
+        # Create or coerce a protobuf request object.
+        request = asset_service.AnalyzeMoveRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.analyze_move,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("resource", request.resource),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
