@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,16 +20,15 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.asset_v1p1beta1.services.asset_service import pagers
 from google.cloud.asset_v1p1beta1.types import asset_service
 from google.cloud.asset_v1p1beta1.types import assets
-
 from .transports.base import AssetServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import AssetServiceGrpcAsyncIOTransport
 from .client import AssetServiceClient
@@ -51,31 +48,57 @@ class AssetServiceAsyncClient:
     parse_common_billing_account_path = staticmethod(
         AssetServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(AssetServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(AssetServiceClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(AssetServiceClient.common_organization_path)
     parse_common_organization_path = staticmethod(
         AssetServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(AssetServiceClient.common_project_path)
     parse_common_project_path = staticmethod(
         AssetServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(AssetServiceClient.common_location_path)
     parse_common_location_path = staticmethod(
         AssetServiceClient.parse_common_location_path
     )
 
-    from_service_account_file = AssetServiceClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            AssetServiceAsyncClient: The constructed client.
+        """
+        return AssetServiceClient.from_service_account_info.__func__(AssetServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            AssetServiceAsyncClient: The constructed client.
+        """
+        return AssetServiceClient.from_service_account_file.__func__(AssetServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> AssetServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             AssetServiceTransport: The transport used by the client instance.
@@ -89,12 +112,12 @@ class AssetServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, AssetServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the asset service client.
+        """Instantiates the asset service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -126,7 +149,6 @@ class AssetServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = AssetServiceClient(
             credentials=credentials,
             transport=transport,
@@ -154,7 +176,7 @@ class AssetServiceAsyncClient:
         requested scope, otherwise it will be rejected.
 
         Args:
-            request (:class:`~.asset_service.SearchAllResourcesRequest`):
+            request (:class:`google.cloud.asset_v1p1beta1.types.SearchAllResourcesRequest`):
                 The request object. Search all resources request.
             scope (:class:`str`):
                 Required. The relative name of an asset. The search is
@@ -165,6 +187,7 @@ class AssetServiceAsyncClient:
                 -  Folder number(such as "folders/1234")
                 -  Project number (such as "projects/12345")
                 -  Project id (such as "projects/abc")
+
                 This corresponds to the ``scope`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -178,10 +201,10 @@ class AssetServiceAsyncClient:
                 this request searches for. If empty, it
                 will search all the supported asset
                 types.
+
                 This corresponds to the ``asset_types`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -189,7 +212,7 @@ class AssetServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.SearchAllResourcesAsyncPager:
+            google.cloud.asset_v1p1beta1.services.asset_service.pagers.SearchAllResourcesAsyncPager:
                 Search all resources response.
                 Iterating over this object will yield
                 results and resolve additional pages
@@ -210,12 +233,10 @@ class AssetServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if scope is not None:
             request.scope = scope
         if query is not None:
             request.query = query
-
         if asset_types:
             request.asset_types.extend(asset_types)
 
@@ -228,9 +249,10 @@ class AssetServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded,
-                    exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=15.0,
             ),
             default_timeout=15.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -243,20 +265,12 @@ class AssetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(
-            request,
-            retry=retry,
-            timeout=timeout,
-            metadata=metadata,
-        )
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.SearchAllResourcesAsyncPager(
-            method=rpc,
-            request=request,
-            response=response,
-            metadata=metadata,
+            method=rpc, request=request, response=response, metadata=metadata,
         )
 
         # Done; return the response.
@@ -282,7 +296,7 @@ class AssetServiceAsyncClient:
         requested scope, otherwise it will be rejected.
 
         Args:
-            request (:class:`~.asset_service.SearchAllIamPoliciesRequest`):
+            request (:class:`google.cloud.asset_v1p1beta1.types.SearchAllIamPoliciesRequest`):
                 The request object. Search all IAM policies request.
             scope (:class:`str`):
                 Required. The relative name of an asset. The search is
@@ -293,6 +307,7 @@ class AssetServiceAsyncClient:
                 -  Folder number(such as "folders/1234")
                 -  Project number (such as "projects/12345")
                 -  Project id (such as "projects/abc")
+
                 This corresponds to the ``scope`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -300,11 +315,11 @@ class AssetServiceAsyncClient:
                 Optional. The query statement. Examples:
 
                 -  "policy:myuser@mydomain.com"
-                -  "policy:(myuser@mydomain.com viewer)".
+                -  "policy:(myuser@mydomain.com viewer)"
+
                 This corresponds to the ``query`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -312,7 +327,7 @@ class AssetServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.SearchAllIamPoliciesAsyncPager:
+            google.cloud.asset_v1p1beta1.services.asset_service.pagers.SearchAllIamPoliciesAsyncPager:
                 Search all IAM policies response.
                 Iterating over this object will yield
                 results and resolve additional pages
@@ -333,7 +348,6 @@ class AssetServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if scope is not None:
             request.scope = scope
         if query is not None:
@@ -348,9 +362,10 @@ class AssetServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded,
-                    exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=15.0,
             ),
             default_timeout=15.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -363,20 +378,12 @@ class AssetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(
-            request,
-            retry=retry,
-            timeout=timeout,
-            metadata=metadata,
-        )
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.SearchAllIamPoliciesAsyncPager(
-            method=rpc,
-            request=request,
-            response=response,
-            metadata=metadata,
+            method=rpc, request=request, response=response, metadata=metadata,
         )
 
         # Done; return the response.
@@ -385,9 +392,7 @@ class AssetServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-asset",
-        ).version,
+        gapic_version=pkg_resources.get_distribution("google-cloud-asset",).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
