@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.cloud.orgpolicy.v1 import orgpolicy_pb2 as orgpolicy  # type: ignore
-from google.iam.v1 import policy_pb2 as policy  # type: ignore
-from google.identity.accesscontextmanager.v1 import access_level_pb2 as giav_access_level  # type: ignore
-from google.identity.accesscontextmanager.v1 import access_policy_pb2 as giav_access_policy  # type: ignore
-from google.identity.accesscontextmanager.v1 import service_perimeter_pb2 as giav_service_perimeter  # type: ignore
-from google.protobuf import struct_pb2 as struct  # type: ignore
+from google.cloud.orgpolicy.v1 import orgpolicy_pb2  # type: ignore
+from google.iam.v1 import policy_pb2  # type: ignore
+from google.identity.accesscontextmanager.v1 import access_level_pb2  # type: ignore
+from google.identity.accesscontextmanager.v1 import access_policy_pb2  # type: ignore
+from google.identity.accesscontextmanager.v1 import service_perimeter_pb2  # type: ignore
+from google.protobuf import struct_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
-    package="google.cloud.asset.v1p5beta1",
-    manifest={
-        "Asset",
-        "Resource",
-    },
+    package="google.cloud.asset.v1p5beta1", manifest={"Asset", "Resource",},
 )
 
 
@@ -49,23 +42,23 @@ class Asset(proto.Message):
         asset_type (str):
             Type of the asset. Example:
             "compute.googleapis.com/Disk".
-        resource (~.assets.Resource):
+        resource (google.cloud.asset_v1p5beta1.types.Resource):
             Representation of the resource.
-        iam_policy (~.policy.Policy):
+        iam_policy (google.iam.v1.policy_pb2.Policy):
             Representation of the actual Cloud IAM policy
             set on a cloud resource. For each resource,
             there must be at most one Cloud IAM policy set
             on it.
-        org_policy (Sequence[~.orgpolicy.Policy]):
+        org_policy (Sequence[google.cloud.orgpolicy.v1.orgpolicy_pb2.Policy]):
             Representation of the Cloud Organization
             Policy set on an asset. For each asset, there
             could be multiple Organization policies with
             different constraints.
-        access_policy (~.giav_access_policy.AccessPolicy):
+        access_policy (google.identity.accesscontextmanager.v1.access_policy_pb2.AccessPolicy):
 
-        access_level (~.giav_access_level.AccessLevel):
+        access_level (google.identity.accesscontextmanager.v1.access_level_pb2.AccessLevel):
 
-        service_perimeter (~.giav_service_perimeter.ServicePerimeter):
+        service_perimeter (google.identity.accesscontextmanager.v1.service_perimeter_pb2.ServicePerimeter):
 
         ancestors (Sequence[str]):
             Asset's ancestry path in Cloud Resource Manager (CRM)
@@ -78,55 +71,36 @@ class Asset(proto.Message):
             "organizations/1234"]
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    asset_type = proto.Field(proto.STRING, number=2)
-
-    resource = proto.Field(
-        proto.MESSAGE,
-        number=3,
-        message="Resource",
-    )
-
-    iam_policy = proto.Field(
-        proto.MESSAGE,
-        number=4,
-        message=policy.Policy,
-    )
-
+    name = proto.Field(proto.STRING, number=1,)
+    asset_type = proto.Field(proto.STRING, number=2,)
+    resource = proto.Field(proto.MESSAGE, number=3, message="Resource",)
+    iam_policy = proto.Field(proto.MESSAGE, number=4, message=policy_pb2.Policy,)
     org_policy = proto.RepeatedField(
-        proto.MESSAGE,
-        number=6,
-        message=orgpolicy.Policy,
+        proto.MESSAGE, number=6, message=orgpolicy_pb2.Policy,
     )
-
     access_policy = proto.Field(
         proto.MESSAGE,
         number=7,
         oneof="access_context_policy",
-        message=giav_access_policy.AccessPolicy,
+        message=access_policy_pb2.AccessPolicy,
     )
-
     access_level = proto.Field(
         proto.MESSAGE,
         number=8,
         oneof="access_context_policy",
-        message=giav_access_level.AccessLevel,
+        message=access_level_pb2.AccessLevel,
     )
-
     service_perimeter = proto.Field(
         proto.MESSAGE,
         number=9,
         oneof="access_context_policy",
-        message=giav_service_perimeter.ServicePerimeter,
+        message=service_perimeter_pb2.ServicePerimeter,
     )
-
-    ancestors = proto.RepeatedField(proto.STRING, number=10)
+    ancestors = proto.RepeatedField(proto.STRING, number=10,)
 
 
 class Resource(proto.Message):
     r"""Representation of a cloud resource.
-
     Attributes:
         version (str):
             The API version. Example: "v1".
@@ -161,27 +135,18 @@ class Resource(proto.Message):
             ``"//cloudresourcemanager.googleapis.com/projects/my_project_123"``.
 
             For third-party assets, it is up to the users to define.
-        data (~.struct.Struct):
+        data (google.protobuf.struct_pb2.Struct):
             The content of the resource, in which some
             sensitive fields are scrubbed away and may not
             be present.
     """
 
-    version = proto.Field(proto.STRING, number=1)
-
-    discovery_document_uri = proto.Field(proto.STRING, number=2)
-
-    discovery_name = proto.Field(proto.STRING, number=3)
-
-    resource_url = proto.Field(proto.STRING, number=4)
-
-    parent = proto.Field(proto.STRING, number=5)
-
-    data = proto.Field(
-        proto.MESSAGE,
-        number=6,
-        message=struct.Struct,
-    )
+    version = proto.Field(proto.STRING, number=1,)
+    discovery_document_uri = proto.Field(proto.STRING, number=2,)
+    discovery_name = proto.Field(proto.STRING, number=3,)
+    resource_url = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(proto.STRING, number=5,)
+    data = proto.Field(proto.MESSAGE, number=6, message=struct_pb2.Struct,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
